@@ -42,14 +42,15 @@ def wrapNebula2Df(nebulaObj):
 
 def pdPlatoTypeSame(pdSeries,gType):
     '''pd.DataFrame的series的数据类型是否和gType一致'''
+    tmpPdSeries=pdSeries.dropna()
     if gType=="string":
-        if pdSeries.dtype==object:
+        if tmpPdSeries.dtype==object:
             return True
     elif gType=="int":
-        if pdSeries.dtype==np.int64:
+        if tmpPdSeries.dtype==np.int64:
             return True
     elif gType=="double":
-        if pdSeries.dtype==np.float64:
+        if tmpPdSeries.dtype==np.float64:
             return True
     return False
 
