@@ -218,15 +218,23 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
             stList=csvDfItem.loc[:,[srcIdAttr,tgtIdAttr]].values.tolist()
             newStList=[]
             csvDfItemList=[]
-            for stPair in tqdm.tqdm(range(0,len(stList),1024),desc="edge attr control-escape"):
-                srcItemType=stPair[0].split("_")[0]
-                srcItemIdVal="_".join(stPair[0].split("_")[1:])
-                tgtItemType=stPair[1].split("_")[0]
-                tgtItemIdVal="_".join(stPair[1].split("_")[1:])
-                if existEdge(srcItemType,srcItemIdVal,srcItemIdVal,tgtItemType,tgtIdAttr,tgtItemIdVal,edgeType,gClient)==False:
-                    newStList.append(stPair)
-                csvDfItemRow=csvDfItem.loc[(csvDfItem[srcIdAttr]==srcItemIdVal)&(csvDfItem[tgtIdAttr]==tgtItemIdVal),:]
-                csvDfItemList.append(csvDfItemRow)
+            batchSize=1024
+            for stPairI in tqdm.tqdm(range(0,len(stList),batchSize),desc="edge attr control-escape"):
+                srcItemType=[stPairItem[0].split("_")[0] for stPairItem in stList[stPairI:stPairI+batchSize]]
+                srcItemIdValList=["_".join(stPairItem[0].split("_")[1:]) for stPairItem in stList[stPairI:stPairI+batchSize]]
+                tgtItemType=[stPairItem[1].split("_")[0] for stPairItem in stList[stPairI:stPairI+batchSize]]
+                tgtItemIdValList=["_".join(stPairItem[1].split("_")[1:]) for stPairItem in stList[stPairI:stPairI+batchSize]]
+                for stPairII in range(len(tgtItemIdValList)):
+                    srcItemIdKey=srcIdAttr
+                    srcItemIdVal=srcItemIdValList[stPairII]
+                    tgtItemIdKey=tgtIdAttr
+                    tgtItemIdVal=tgtItemIdValList[stPairII]
+                    if existEdge(srcItemType,srcItemIdKey,srcItemIdVal,tgtItemType,tgtItemIdKey,tgtItemIdVal,edgeType,gClient)==False:
+                        srcKV="{}_{}".format(srcItemType,srcItemIdVal)
+                        tgtKV="{}_{}".format(tgtItemIdKey,tgtItemIdVal)
+                        newStList.append([srcKV,tgtKV])
+                        csvDfItemRow={srcIdAttr:srcKV,tgtIdAttr:tgtKV}
+                        csvDfItemList.append(csvDfItemRow)
             csvDfItem=pd.concat(csvDfItemList)
         elif edgeAttrDataProcess=="plus":
             htList=json.loads(csvDfItem.to_json(orient="records"))
