@@ -26,23 +26,30 @@ def buildVertex(vertexJson,graphClient,nodeSysIDUUID=True):
             attrTypeList=[]
             for attrKeyItem in csv_attr2type_map:
                 if attrKeyItem in  csv2plato_attr_map and csv2plato_attr_map[attrKeyItem] in gNodeAttrList:
-                    if pdPlatoTypeSame(vertexDf[attrKeyItem],csv_attr2type_map[attrKeyItem]):
+                    if attrKeyItem==idCol:
                         attrTypeList.append({
                                 "name": csv2plato_attr_map[attrKeyItem],
-                                "type": csv_attr2type_map[attrKeyItem],
+                                "type": "string",
                                 "index": list(vertexDf.columns).index(attrKeyItem)
                             })
                     else:
-                        if csv_attr2type_map[attrKeyItem]=="string":
-                            vertexDf[attrKeyItem]=vertexDf[attrKeyItem].fillna("null")
                         if pdPlatoTypeSame(vertexDf[attrKeyItem],csv_attr2type_map[attrKeyItem]):
                             attrTypeList.append({
                                     "name": csv2plato_attr_map[attrKeyItem],
                                     "type": csv_attr2type_map[attrKeyItem],
                                     "index": list(vertexDf.columns).index(attrKeyItem)
                                 })
+                        elif csv_attr2type_map[attrKeyItem]=="string":
+                            vertexDf[attrKeyItem]=vertexDf[attrKeyItem].fillna("null")
+                            vertexDf[attrKeyItem]=vertexDf[attrKeyItem].astype(str)
+                            attrTypeList.append({
+                                    "name": csv2plato_attr_map[attrKeyItem],
+                                    "type": csv_attr2type_map[attrKeyItem],
+                                    "index": list(vertexDf.columns).index(attrKeyItem)
+                                })
                         else:
-                            raise TypeError("csv与uploadSchema.json类型冲突，请核查{}，csv中是{}，而platodb中是{}".format(attrKeyItem,vertexDf[attrKeyItem].dtype,csv_attr2type_map[attrKeyItem]))
+                            raise TypeError("csv({}_{})与uploadSchema.json类型冲突，请核查".format(vertexPath.split("/")[-1],
+                                                                                            attrKeyItem))
             uuidFunDict={"function":"uuid"} if nodeSysIDUUID else {}
             vertexItemJson={
                         "path": "/upload-dir/{}".format(vertexFileName),
@@ -90,22 +97,14 @@ def buildEdge(edgeJson,graphClient,srcSysIDUUID=True,tgtSysIDUUID=True):
         for attrKeyItem in csv_attr2type_map:
             if attrKeyItem in  csv2plato_attr_map and csv2plato_attr_map[attrKeyItem] in gEdgeAttrList:
                 if pdPlatoTypeSame(edgeDf[attrKeyItem],csv_attr2type_map[attrKeyItem]):
-                        attrTypeList.append({
-                                "name": csv2plato_attr_map[attrKeyItem],
-                                "type": csv_attr2type_map[attrKeyItem],
-                                "index": list(edgeDf.columns).index(attrKeyItem)
-                            })
+                    attrTypeList.append({
+                            "name": csv2plato_attr_map[attrKeyItem],
+                            "type": csv_attr2type_map[attrKeyItem],
+                            "index": list(edgeDf.columns).index(attrKeyItem)
+                        })
                 else:
-                    if csv_attr2type_map[attrKeyItem]=="string":
-                        edgeDf[attrKeyItem]=edgeDf[attrKeyItem].fillna("null")
-                    if pdPlatoTypeSame(edgeDf[attrKeyItem],csv_attr2type_map[attrKeyItem]):
-                        attrTypeList.append({
-                                "name": csv2plato_attr_map[attrKeyItem],
-                                "type": csv_attr2type_map[attrKeyItem],
-                                "index": list(edgeDf.columns).index(attrKeyItem)
-                            })
-                    else:
-                        raise TypeError("csv与uploadSchema.json类型冲突，请核查{}，csv中是{}，而platodb中是{}".format(attrKeyItem,edgeDf[attrKeyItem].dtype,csv_attr2type_map[attrKeyItem]))
+                    raise TypeError("csv({}_{})与uploadSchema.json类型冲突，请核查".format(edgePath.split("/")[-1],
+                                                                                            attrKeyItem))
 
         srcVIDDict={"function": "uuid"} if srcSysIDUUID else {}
         tgtVIDDict={"function": "uuid"} if tgtSysIDUUID else {}
@@ -206,8 +205,8 @@ def submitSchema(schemaJson,gUrl="http://9.135.95.249:7001"):
         'Accept': 'application/json, text/plain, */*',
         'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.107 Safari/537.36 Edg/92.0.902.62',
         'Content-Type': 'application/json',
-        'Origin': 'http://9.135.95.249:7001',
-        'Referer': 'http://9.135.95.249:7001/import',
+        'Origin': gUrl,
+        'Referer': '{}/import'.format(gUrl),
         'Accept-Language': 'zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6',
         'Cookie': '_ga=GA1.1.599074290.1616395720; locale=ZH_CN; Hm_lvt_b9cb5b394fd669583c13f8975ca64ff0=1627524967,1627612772,1627879099,1627959086; nsid=de94b8d118e557ff3e54875946395226; nh=9.135.95.249:13708; nu=root; np=nebula; _gid=GA1.1.1256907028.1628059656; Hm_lpvt_b9cb5b394fd669583c13f8975ca64ff0=1628063018'
     }
@@ -226,7 +225,7 @@ if __name__=="__main__":
     guser="root"
     gpassword="nebula"
     gspace="post_skill_school_ianxu"
-    gAPIUrl="http://9.135.95.249:7001"
+    gUrl="http://9.135.95.249:7001"
 
     schemaPath="csv2platodb/attr2Vertex_1629250000"
     
@@ -274,7 +273,6 @@ if __name__=="__main__":
         ]
     }
     '''
-    
     with open(os.path.join(schemaPath,"uploadSchema.json")) as uploadSchemaFile:
         uploadSchemaJson=json.load(uploadSchemaFile)
     
@@ -309,6 +307,6 @@ if __name__=="__main__":
     with open(os.path.join(schemaPath,"schemaJson.json"),"w+") as schemaJsonFile:
         json.dump(schemaJson,schemaJsonFile)
         
-    resDict=submitSchema(schemaJson,gUrl=gAPIUrl)
+    resDict=submitSchema(schemaJson,gUrl=gUrl)
     
-    print(resDict)
+    print(resDict)
\ No newline at end of file
